#[non_exhaustive]pub struct PollMedia {
pub text: Option<String>,
pub emoji: Option<PollMediaEmoji>,
}Expand description
A piece of data used in mutliple parts of the Poll structure.
Currently holds text and an optional emoji, but this is expected to change in future
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: Option<String>emoji: Option<PollMediaEmoji>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PollMedia
impl<'de> Deserialize<'de> for PollMedia
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PollMedia, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PollMedia, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for PollMedia
impl Serialize for PollMedia
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more